Subject: [bug#29103] [PATCH 3/6] gnu: kdelibs4support: Make test kstandarddirstest pass.

From: Hartmut Goebel <[email-masked]>
Date: Wed, 1 Nov 2017 15:41:43 +0100

* gnu/package/kde-frameworks.scm(kdelibs4support)[#:phases]
  <check-post-install>: Add workaround for bug in test-case.
  Update comment.
---
 gnu/packages/kde-frameworks.scm | 7 +++++--
 1 file changed, 5 insertions(+), 2 deletions(-)

diff --git a/gnu/packages/kde-frameworks.scm b/gnu/packages/kde-frameworks.scm
index 28a10de4b..c1cf4e4aa 100644
--- a/gnu/packages/kde-frameworks.scm
+++ b/gnu/packages/kde-frameworks.scm
@@ -3348,8 +3348,11 @@ workspace.")
              ;; enable debug output
              (setenv "CTEST_OUTPUT_ON_FAILURE" "1") ; enable debug output
              (setenv "DBUS_FATAL_WARNINGS" "0")
-             ;; TODO: Make this tests pass (also see
-             ;; https://bugs.kde.org/381098)
+             ;; Make kstandarddirstest pass (see https://bugs.kde.org/381098)
+             (mkdir-p ".kde-unit-test/xdg/config")
+             (with-output-to-file ".kde-unit-test/xdg/config/foorc"
+               (lambda () #t))  ;; simply touch the file
+             ;; kuniqueapptest hangs. TODO: Make this test pass.
              (zero? (system* "dbus-launch" "ctest" "."
                              "-E" "kstandarddirstest|kuniqueapptest")))))))
     (home-page "https://community.kde.org/Frameworks")
-- 
2.13.5